@@ -13,8 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
+from google.cloud.firestore_v1.types import aggregation_result
 from google.cloud.firestore_v1.types import common
 from google.cloud.firestore_v1.types import document as gf_document
 from google.cloud.firestore_v1.types import query as gf_query
@@ -41,6 +44,8 @@ __protobuf__ = proto.module(
         "RollbackRequest",
         "RunQueryRequest",
         "RunQueryResponse",
+        "RunAggregationQueryRequest",
+        "RunAggregationQueryResponse",
         "PartitionQueryRequest",
         "PartitionQueryResponse",
         "WriteRequest",
@@ -91,21 +96,21 @@ class GetDocumentRequest(proto.Message):
             This field is a member of `oneof`_ ``consistency_selector``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    mask = proto.Field(
+    mask: common.DocumentMask = proto.Field(
         proto.MESSAGE,
         number=2,
         message=common.DocumentMask,
     )
-    transaction = proto.Field(
+    transaction: bytes = proto.Field(
         proto.BYTES,
         number=3,
         oneof="consistency_selector",
     )
-    read_time = proto.Field(
+    read_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="consistency_selector",
@@ -173,43 +178,43 @@ class ListDocumentsRequest(proto.Message):
             ``order_by``.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    collection_id = proto.Field(
+    collection_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=3,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    order_by = proto.Field(
+    order_by: str = proto.Field(
         proto.STRING,
         number=6,
     )
-    mask = proto.Field(
+    mask: common.DocumentMask = proto.Field(
         proto.MESSAGE,
         number=7,
         message=common.DocumentMask,
     )
-    transaction = proto.Field(
+    transaction: bytes = proto.Field(
         proto.BYTES,
         number=8,
         oneof="consistency_selector",
     )
-    read_time = proto.Field(
+    read_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=10,
         oneof="consistency_selector",
         message=timestamp_pb2.Timestamp,
     )
-    show_missing = proto.Field(
+    show_missing: bool = proto.Field(
         proto.BOOL,
         number=12,
     )
@@ -220,7 +225,7 @@ class ListDocumentsResponse(proto.Message):
     [Firestore.ListDocuments][google.firestore.v1.Firestore.ListDocuments].
 
     Attributes:
-        documents (Sequence[google.cloud.firestore_v1.types.Document]):
+        documents (MutableSequence[google.cloud.firestore_v1.types.Document]):
             The Documents found.
         next_page_token (str):
             The next page token.
@@ -230,12 +235,12 @@ class ListDocumentsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    documents = proto.RepeatedField(
+    documents: MutableSequence[gf_document.Document] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=gf_document.Document,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -269,24 +274,24 @@ class CreateDocumentRequest(proto.Message):
             the response.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    collection_id = proto.Field(
+    collection_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    document_id = proto.Field(
+    document_id: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    document = proto.Field(
+    document: gf_document.Document = proto.Field(
         proto.MESSAGE,
         number=4,
         message=gf_document.Document,
     )
-    mask = proto.Field(
+    mask: common.DocumentMask = proto.Field(
         proto.MESSAGE,
         number=5,
         message=common.DocumentMask,
@@ -324,22 +329,22 @@ class UpdateDocumentRequest(proto.Message):
             by the target document.
     """
 
-    document = proto.Field(
+    document: gf_document.Document = proto.Field(
         proto.MESSAGE,
         number=1,
         message=gf_document.Document,
     )
-    update_mask = proto.Field(
+    update_mask: common.DocumentMask = proto.Field(
         proto.MESSAGE,
         number=2,
         message=common.DocumentMask,
     )
-    mask = proto.Field(
+    mask: common.DocumentMask = proto.Field(
         proto.MESSAGE,
         number=3,
         message=common.DocumentMask,
     )
-    current_document = proto.Field(
+    current_document: common.Precondition = proto.Field(
         proto.MESSAGE,
         number=4,
         message=common.Precondition,
@@ -361,11 +366,11 @@ class DeleteDocumentRequest(proto.Message):
             by the target document.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    current_document = proto.Field(
+    current_document: common.Precondition = proto.Field(
         proto.MESSAGE,
         number=2,
         message=common.Precondition,
@@ -387,7 +392,7 @@ class BatchGetDocumentsRequest(proto.Message):
         database (str):
             Required. The database name. In the format:
             ``projects/{project_id}/databases/{database_id}``.
-        documents (Sequence[str]):
+        documents (MutableSequence[str]):
             The names of the documents to retrieve. In the format:
             ``projects/{project_id}/databases/{database_id}/documents/{document_path}``.
             The request will fail if any of the document is not a child
@@ -417,31 +422,31 @@ class BatchGetDocumentsRequest(proto.Message):
             This field is a member of `oneof`_ ``consistency_selector``.
     """
 
-    database = proto.Field(
+    database: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    documents = proto.RepeatedField(
+    documents: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=2,
     )
-    mask = proto.Field(
+    mask: common.DocumentMask = proto.Field(
         proto.MESSAGE,
         number=3,
         message=common.DocumentMask,
     )
-    transaction = proto.Field(
+    transaction: bytes = proto.Field(
         proto.BYTES,
         number=4,
         oneof="consistency_selector",
     )
-    new_transaction = proto.Field(
+    new_transaction: common.TransactionOptions = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="consistency_selector",
         message=common.TransactionOptions,
     )
-    read_time = proto.Field(
+    read_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=7,
         oneof="consistency_selector",
@@ -483,22 +488,22 @@ class BatchGetDocumentsResponse(proto.Message):
             between their read_time and this one.
     """
 
-    found = proto.Field(
+    found: gf_document.Document = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="result",
         message=gf_document.Document,
     )
-    missing = proto.Field(
+    missing: str = proto.Field(
         proto.STRING,
         number=2,
         oneof="result",
     )
-    transaction = proto.Field(
+    transaction: bytes = proto.Field(
         proto.BYTES,
         number=3,
     )
-    read_time = proto.Field(
+    read_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=4,
         message=timestamp_pb2.Timestamp,
@@ -518,11 +523,11 @@ class BeginTransactionRequest(proto.Message):
             Defaults to a read-write transaction.
     """
 
-    database = proto.Field(
+    database: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    options = proto.Field(
+    options: common.TransactionOptions = proto.Field(
         proto.MESSAGE,
         number=2,
         message=common.TransactionOptions,
@@ -538,7 +543,7 @@ class BeginTransactionResponse(proto.Message):
             The transaction that was started.
     """
 
-    transaction = proto.Field(
+    transaction: bytes = proto.Field(
         proto.BYTES,
         number=1,
     )
@@ -552,7 +557,7 @@ class CommitRequest(proto.Message):
         database (str):
             Required. The database name. In the format:
             ``projects/{project_id}/databases/{database_id}``.
-        writes (Sequence[google.cloud.firestore_v1.types.Write]):
+        writes (MutableSequence[google.cloud.firestore_v1.types.Write]):
             The writes to apply.
             Always executed atomically and in order.
         transaction (bytes):
@@ -560,16 +565,16 @@ class CommitRequest(proto.Message):
             transaction, and commits it.
     """
 
-    database = proto.Field(
+    database: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    writes = proto.RepeatedField(
+    writes: MutableSequence[write.Write] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message=write.Write,
     )
-    transaction = proto.Field(
+    transaction: bytes = proto.Field(
         proto.BYTES,
         number=3,
     )
@@ -580,7 +585,7 @@ class CommitResponse(proto.Message):
     [Firestore.Commit][google.firestore.v1.Firestore.Commit].
 
     Attributes:
-        write_results (Sequence[google.cloud.firestore_v1.types.WriteResult]):
+        write_results (MutableSequence[google.cloud.firestore_v1.types.WriteResult]):
             The result of applying the writes.
             This i-th write result corresponds to the i-th
             write in the request.
@@ -590,12 +595,12 @@ class CommitResponse(proto.Message):
             effects of the commit.
     """
 
-    write_results = proto.RepeatedField(
+    write_results: MutableSequence[write.WriteResult] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=write.WriteResult,
     )
-    commit_time = proto.Field(
+    commit_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
@@ -614,11 +619,11 @@ class RollbackRequest(proto.Message):
             Required. The transaction to roll back.
     """
 
-    database = proto.Field(
+    database: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    transaction = proto.Field(
+    transaction: bytes = proto.Field(
         proto.BYTES,
         number=2,
     )
@@ -669,28 +674,28 @@ class RunQueryRequest(proto.Message):
             This field is a member of `oneof`_ ``consistency_selector``.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    structured_query = proto.Field(
+    structured_query: gf_query.StructuredQuery = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="query_type",
         message=gf_query.StructuredQuery,
     )
-    transaction = proto.Field(
+    transaction: bytes = proto.Field(
         proto.BYTES,
         number=5,
         oneof="consistency_selector",
     )
-    new_transaction = proto.Field(
+    new_transaction: common.TransactionOptions = proto.Field(
         proto.MESSAGE,
         number=6,
         oneof="consistency_selector",
         message=common.TransactionOptions,
     )
-    read_time = proto.Field(
+    read_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=7,
         oneof="consistency_selector",
@@ -736,31 +741,142 @@ class RunQueryResponse(proto.Message):
             This field is a member of `oneof`_ ``continuation_selector``.
     """
 
-    transaction = proto.Field(
+    transaction: bytes = proto.Field(
         proto.BYTES,
         number=2,
     )
-    document = proto.Field(
+    document: gf_document.Document = proto.Field(
         proto.MESSAGE,
         number=1,
         message=gf_document.Document,
     )
-    read_time = proto.Field(
+    read_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
     )
-    skipped_results = proto.Field(
+    skipped_results: int = proto.Field(
         proto.INT32,
         number=4,
     )
-    done = proto.Field(
+    done: bool = proto.Field(
         proto.BOOL,
         number=6,
         oneof="continuation_selector",
     )
 
 
+class RunAggregationQueryRequest(proto.Message):
+    r"""The request for
+    [Firestore.RunAggregationQuery][google.firestore.v1.Firestore.RunAggregationQuery].
+
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
+    Attributes:
+        parent (str):
+            Required. The parent resource name. In the format:
+            ``projects/{project_id}/databases/{database_id}/documents``
+            or
+            ``projects/{project_id}/databases/{database_id}/documents/{document_path}``.
+            For example:
+            ``projects/my-project/databases/my-database/documents`` or
+            ``projects/my-project/databases/my-database/documents/chatrooms/my-chatroom``
+        structured_aggregation_query (google.cloud.firestore_v1.types.StructuredAggregationQuery):
+            An aggregation query.
+
+            This field is a member of `oneof`_ ``query_type``.
+        transaction (bytes):
+            Run the aggregation within an already active
+            transaction.
+            The value here is the opaque transaction ID to
+            execute the query in.
+
+            This field is a member of `oneof`_ ``consistency_selector``.
+        new_transaction (google.cloud.firestore_v1.types.TransactionOptions):
+            Starts a new transaction as part of the
+            query, defaulting to read-only.
+            The new transaction ID will be returned as the
+            first response in the stream.
+
+            This field is a member of `oneof`_ ``consistency_selector``.
+        read_time (google.protobuf.timestamp_pb2.Timestamp):
+            Executes the query at the given timestamp.
+
+            Requires:
+
+            -  Cannot be more than 270 seconds in the past.
+
+            This field is a member of `oneof`_ ``consistency_selector``.
+    """
+
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    structured_aggregation_query: gf_query.StructuredAggregationQuery = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        oneof="query_type",
+        message=gf_query.StructuredAggregationQuery,
+    )
+    transaction: bytes = proto.Field(
+        proto.BYTES,
+        number=4,
+        oneof="consistency_selector",
+    )
+    new_transaction: common.TransactionOptions = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        oneof="consistency_selector",
+        message=common.TransactionOptions,
+    )
+    read_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        oneof="consistency_selector",
+        message=timestamp_pb2.Timestamp,
+    )
+
+
+class RunAggregationQueryResponse(proto.Message):
+    r"""The response for
+    [Firestore.RunAggregationQuery][google.firestore.v1.Firestore.RunAggregationQuery].
+
+    Attributes:
+        result (google.cloud.firestore_v1.types.AggregationResult):
+            A single aggregation result.
+            Not present when reporting partial progress.
+        transaction (bytes):
+            The transaction that was started as part of
+            this request.
+            Only present on the first response when the
+            request requested to start a new transaction.
+        read_time (google.protobuf.timestamp_pb2.Timestamp):
+            The time at which the aggregate value is
+            valid for.
+    """
+
+    result: aggregation_result.AggregationResult = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=aggregation_result.AggregationResult,
+    )
+    transaction: bytes = proto.Field(
+        proto.BYTES,
+        number=2,
+    )
+    read_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+
+
 class PartitionQueryRequest(proto.Message):
     r"""The request for
     [Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery].
@@ -828,29 +944,29 @@ class PartitionQueryRequest(proto.Message):
             This field is a member of `oneof`_ ``consistency_selector``.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    structured_query = proto.Field(
+    structured_query: gf_query.StructuredQuery = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="query_type",
         message=gf_query.StructuredQuery,
     )
-    partition_count = proto.Field(
+    partition_count: int = proto.Field(
         proto.INT64,
         number=3,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=5,
     )
-    read_time = proto.Field(
+    read_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=6,
         oneof="consistency_selector",
@@ -863,7 +979,7 @@ class PartitionQueryResponse(proto.Message):
     [Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery].
 
     Attributes:
-        partitions (Sequence[google.cloud.firestore_v1.types.Cursor]):
+        partitions (MutableSequence[google.cloud.firestore_v1.types.Cursor]):
             Partition results. Each partition is a split point that can
             be used by RunQuery as a starting or end point for the query
             results. The RunQuery requests must be made with the same
@@ -892,12 +1008,12 @@ class PartitionQueryResponse(proto.Message):
     def raw_page(self):
         return self
 
-    partitions = proto.RepeatedField(
+    partitions: MutableSequence[gf_query.Cursor] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=gf_query.Cursor,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -926,7 +1042,7 @@ class WriteRequest(proto.Message):
             The ID of the write stream to resume.
             This may only be set in the first message. When
             left empty, a new write stream will be created.
-        writes (Sequence[google.cloud.firestore_v1.types.Write]):
+        writes (MutableSequence[google.cloud.firestore_v1.types.Write]):
             The writes to apply.
             Always executed atomically and in order.
             This must be empty on the first request.
@@ -949,28 +1065,28 @@ class WriteRequest(proto.Message):
             ``stream_id`` field.
 
             Leave this field unset when creating a new stream.
-        labels (Mapping[str, str]):
+        labels (MutableMapping[str, str]):
             Labels associated with this write request.
     """
 
-    database = proto.Field(
+    database: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    stream_id = proto.Field(
+    stream_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    writes = proto.RepeatedField(
+    writes: MutableSequence[write.Write] = proto.RepeatedField(
         proto.MESSAGE,
         number=3,
         message=write.Write,
     )
-    stream_token = proto.Field(
+    stream_token: bytes = proto.Field(
         proto.BYTES,
         number=4,
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=5,
@@ -991,7 +1107,7 @@ class WriteResponse(proto.Message):
             response in the stream. This can be used by a
             client to resume the stream at this point.
             This field is always set.
-        write_results (Sequence[google.cloud.firestore_v1.types.WriteResult]):
+        write_results (MutableSequence[google.cloud.firestore_v1.types.WriteResult]):
             The result of applying the writes.
             This i-th write result corresponds to the i-th
             write in the request.
@@ -1001,20 +1117,20 @@ class WriteResponse(proto.Message):
             effects of the write.
     """
 
-    stream_id = proto.Field(
+    stream_id: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    stream_token = proto.Field(
+    stream_token: bytes = proto.Field(
         proto.BYTES,
         number=2,
     )
-    write_results = proto.RepeatedField(
+    write_results: MutableSequence[write.WriteResult] = proto.RepeatedField(
         proto.MESSAGE,
         number=3,
         message=write.WriteResult,
     )
-    commit_time = proto.Field(
+    commit_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=4,
         message=timestamp_pb2.Timestamp,
@@ -1045,26 +1161,26 @@ class ListenRequest(proto.Message):
             stream.
 
             This field is a member of `oneof`_ ``target_change``.
-        labels (Mapping[str, str]):
+        labels (MutableMapping[str, str]):
             Labels associated with this target change.
     """
 
-    database = proto.Field(
+    database: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    add_target = proto.Field(
+    add_target: "Target" = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="target_change",
         message="Target",
     )
-    remove_target = proto.Field(
+    remove_target: int = proto.Field(
         proto.INT32,
         number=3,
         oneof="target_change",
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=4,
@@ -1112,31 +1228,31 @@ class ListenResponse(proto.Message):
             This field is a member of `oneof`_ ``response_type``.
     """
 
-    target_change = proto.Field(
+    target_change: "TargetChange" = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="response_type",
         message="TargetChange",
     )
-    document_change = proto.Field(
+    document_change: write.DocumentChange = proto.Field(
         proto.MESSAGE,
         number=3,
         oneof="response_type",
         message=write.DocumentChange,
     )
-    document_delete = proto.Field(
+    document_delete: write.DocumentDelete = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="response_type",
         message=write.DocumentDelete,
     )
-    document_remove = proto.Field(
+    document_remove: write.DocumentRemove = proto.Field(
         proto.MESSAGE,
         number=6,
         oneof="response_type",
         message=write.DocumentRemove,
     )
-    filter = proto.Field(
+    filter: write.ExistenceFilter = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="response_type",
@@ -1193,7 +1309,7 @@ class Target(proto.Message):
         r"""A target specified by a set of documents names.
 
         Attributes:
-            documents (Sequence[str]):
+            documents (MutableSequence[str]):
                 The names of the documents to retrieve. In the format:
                 ``projects/{project_id}/databases/{database_id}/documents/{document_path}``.
                 The request will fail if any of the document is not a child
@@ -1201,7 +1317,7 @@ class Target(proto.Message):
                 elided.
         """
 
-        documents = proto.RepeatedField(
+        documents: MutableSequence[str] = proto.RepeatedField(
             proto.STRING,
             number=2,
         )
@@ -1226,45 +1342,45 @@ class Target(proto.Message):
                 This field is a member of `oneof`_ ``query_type``.
         """
 
-        parent = proto.Field(
+        parent: str = proto.Field(
             proto.STRING,
             number=1,
         )
-        structured_query = proto.Field(
+        structured_query: gf_query.StructuredQuery = proto.Field(
             proto.MESSAGE,
             number=2,
             oneof="query_type",
             message=gf_query.StructuredQuery,
         )
 
-    query = proto.Field(
+    query: QueryTarget = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="target_type",
         message=QueryTarget,
     )
-    documents = proto.Field(
+    documents: DocumentsTarget = proto.Field(
         proto.MESSAGE,
         number=3,
         oneof="target_type",
         message=DocumentsTarget,
     )
-    resume_token = proto.Field(
+    resume_token: bytes = proto.Field(
         proto.BYTES,
         number=4,
         oneof="resume_type",
     )
-    read_time = proto.Field(
+    read_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=11,
         oneof="resume_type",
         message=timestamp_pb2.Timestamp,
     )
-    target_id = proto.Field(
+    target_id: int = proto.Field(
         proto.INT32,
         number=5,
     )
-    once = proto.Field(
+    once: bool = proto.Field(
         proto.BOOL,
         number=6,
     )
@@ -1276,7 +1392,7 @@ class TargetChange(proto.Message):
     Attributes:
         target_change_type (google.cloud.firestore_v1.types.TargetChange.TargetChangeType):
             The type of change that occurred.
-        target_ids (Sequence[int]):
+        target_ids (MutableSequence[int]):
             The target IDs of targets that have changed.
             If empty, the change applies to all targets.
 
@@ -1312,25 +1428,25 @@ class TargetChange(proto.Message):
         CURRENT = 3
         RESET = 4
 
-    target_change_type = proto.Field(
+    target_change_type: TargetChangeType = proto.Field(
         proto.ENUM,
         number=1,
         enum=TargetChangeType,
     )
-    target_ids = proto.RepeatedField(
+    target_ids: MutableSequence[int] = proto.RepeatedField(
         proto.INT32,
         number=2,
     )
-    cause = proto.Field(
+    cause: status_pb2.Status = proto.Field(
         proto.MESSAGE,
         number=3,
         message=status_pb2.Status,
     )
-    resume_token = proto.Field(
+    resume_token: bytes = proto.Field(
         proto.BYTES,
         number=4,
     )
-    read_time = proto.Field(
+    read_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=6,
         message=timestamp_pb2.Timestamp,
@@ -1362,19 +1478,19 @@ class ListCollectionIdsRequest(proto.Message):
             This field is a member of `oneof`_ ``consistency_selector``.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    read_time = proto.Field(
+    read_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="consistency_selector",
@@ -1387,7 +1503,7 @@ class ListCollectionIdsResponse(proto.Message):
     [Firestore.ListCollectionIds][google.firestore.v1.Firestore.ListCollectionIds].
 
     Attributes:
-        collection_ids (Sequence[str]):
+        collection_ids (MutableSequence[str]):
             The collection ids.
         next_page_token (str):
             A page token that may be used to continue the
@@ -1398,11 +1514,11 @@ class ListCollectionIdsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    collection_ids = proto.RepeatedField(
+    collection_ids: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=1,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -1416,26 +1532,26 @@ class BatchWriteRequest(proto.Message):
         database (str):
             Required. The database name. In the format:
             ``projects/{project_id}/databases/{database_id}``.
-        writes (Sequence[google.cloud.firestore_v1.types.Write]):
+        writes (MutableSequence[google.cloud.firestore_v1.types.Write]):
             The writes to apply.
             Method does not apply writes atomically and does
             not guarantee ordering. Each write succeeds or
             fails independently. You cannot write to the
             same document more than once per request.
-        labels (Mapping[str, str]):
+        labels (MutableMapping[str, str]):
             Labels associated with this batch write.
     """
 
-    database = proto.Field(
+    database: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    writes = proto.RepeatedField(
+    writes: MutableSequence[write.Write] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message=write.Write,
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=3,
@@ -1447,22 +1563,22 @@ class BatchWriteResponse(proto.Message):
     [Firestore.BatchWrite][google.firestore.v1.Firestore.BatchWrite].
 
     Attributes:
-        write_results (Sequence[google.cloud.firestore_v1.types.WriteResult]):
+        write_results (MutableSequence[google.cloud.firestore_v1.types.WriteResult]):
             The result of applying the writes.
             This i-th write result corresponds to the i-th
             write in the request.
-        status (Sequence[google.rpc.status_pb2.Status]):
+        status (MutableSequence[google.rpc.status_pb2.Status]):
             The status of applying the writes.
             This i-th write status corresponds to the i-th
             write in the request.
     """
 
-    write_results = proto.RepeatedField(
+    write_results: MutableSequence[write.WriteResult] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=write.WriteResult,
     )
-    status = proto.RepeatedField(
+    status: MutableSequence[status_pb2.Status] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message=status_pb2.Status,
